<?php
/*
 * conn_potok.php
 *
 * Created on 21.08.2008
 */
require_once(dirname(__FILE__).'/constants.php');
if (POTOK_CONNECTIVITY_ENABLED) {
	require_once 'MDB2.php';
	//PEAR::setErrorHandling(PEAR_ERROR_DIE);
	//PEAR::setErrorHandling(PEAR_ERROR_PRINT);
	PEAR::setErrorHandling(PEAR_ERROR_RETURN);
}

/**
 * getDBErrorStr - Returns full info from PEAR::DB_Error
 */
if (!function_exists('getDBErrorStr')) {
	function getDBErrorStr($dberrobj, $sep) {
		if (PEAR::isError($dberrobj)) {
			$dbmsg = $dberrobj->getUserInfo();
			$dbmsgd = $dberrobj->getDebugInfo();
			if (strcmp($dbmsg, $dbmsgd) == 0) {
				$dbmsgd = "";
			} else {
				$dbmsgd = $sep."dbdebug: ".$dbmsgd;
			}
			return "msg: ".$dberrobj->getMessage()."(".$dberrobj->getCode().")".$sep
				. "dbmsg: ".$dbmsg.$dbmsgd;
		} else {
			return "";
		}
	}
}

class POTOK_CONNECTION {
	public $connection;         //The database connection
	public $db_ok;              //Indicates problems connecting to database

	/* Class constructor */
	function POTOK_CONNECTION() {
		global $logger;

		/* Make connection to database */
		$dsn = POTOK_DB_ENGINE.'://'.POTOK_DB_USER.':'.POTOK_DB_PASS.'@'.POTOK_DB_HOST.'/'.POTOK_DB_FILE;
		$this->connection =& MDB2::factory($dsn, false);
		if (PEAR::isError($this->connection)) {
			$this->db_ok = false;
			$logger->log("POTOK_CONNECTION Fatal Error:\n".getDBErrorStr($this->connection, "\n"));
			return;
		}
		$this->db_ok = true;
		$logger->log("POTOK_CONNECTION Initialized.");

		$this->connection->setOption('field_case', CASE_LOWER);
		$this->connection->setOption('portability', MDB2_PORTABILITY_NUMROWS | MDB2_PORTABILITY_FIX_CASE);
		$this->connection->setFetchMode(MDB2_FETCHMODE_ASSOC);
		//$this->connection->setFetchMode(MDB2_FETCHMODE_OBJECT);
		$this->connection->LoadModule('Extended');
	}

	/**
	 * getProcResultAsArray
	 */
	function getQueryResultAsArray($query){
		global $logger;

		$result = $this->connection->queryAll($query);
		if (PEAR::isError($result)) {
			$logger->log("getQueryResultAsArray($query) ERR:\n".print_r($result, true));
			$result = null;
		}
		return $result;
	}

	/**
	 * query - Performs the given query on the database and
	 * returns the result, which may be false, true or a
	 * resource identifier.
	 */
	function query($query){
		return $this->connection->query($query);
	}

	/**
	 * getAccountInfo
	 */
	function getAccountInfo($accountid = null, $number = null, $dogovorid = null) {
		global $logger;

		$accountid = $accountid !== null ? intval($accountid) : 'null';
		$number = $number !== null ? "'$number'" : 'null';
		$dogovorid = $dogovorid !== null ? "'$dogovorid'" : 'null';

		$q = "select * from GET_ACCOUNT_INFO($accountid, $number, $dogovorid, -1)";
		$logger->log("getAccountInfo($q)...");
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("getAccountInfo($q):".print_r($result, true));
			return null;
		}

		return $result;
	}

	/**
	 * updateAccountInfo
	 */
	function updateAccountInfo($accountid, $pay, $providerid) {
		global $logger;

		$q = "select * from UPDATE_ACCOUNT_INFO($accountid, $pay, $providerid, null)";
		$logger->log("updateAccountInfo($q)...\n");
		$result = $this->connection->query($q);
		if (PEAR::isError($result)) {
			$logger->log("updateAccountInfo($q):ERR=\n".print_r($result, true));
			return null;
		}

		$result = $result->fetchRow();
		$logger->log("updateAccountInfo($q):OK=\n".print_r($result, true));
		return $result;
	}

};

$conn_potok = POTOK_CONNECTIVITY_ENABLED ? new POTOK_CONNECTION : null;

?>
