<?php
/**
 * Session.php
 */
require_once(dirname(__FILE__).'/stk_database.php');
require_once(dirname(__FILE__).'/mailer.php');
require_once(dirname(__FILE__).'/form.php');

class Session
{
	public $syssession;				//_SESSION proxy
	public $db_ok;

	public $username;
	public $userid;

	public $ofid;
	public $ofinfo;

	public $userlevel;
	public $time;         //Time user was last active (page loaded)
	public $logged_in;    //True if user is logged in, false otherwise
	public $userinfo = array();
	public $url;
	public $referrer;

	public $stk_accountinfo = array();
	public $stk_accountinfoex;
	public $stk_accountid; //stk account
	public $stk_emitterkcid;
	public $stk_ownerkcid;
	public $stk_accountcurrencyid;
	public $stk_pin;

	public $stk_case_login;

	public function __set($name, $value) {
		$this->syssession[$this->userid][$name] = $value;
	}

	public function __get($name) {
		if (array_key_exists($name, $this->syssession[$this->userid]))
			return $this->syssession[$this->userid][$name];

		/*$trace = debug_backtrace();
		trigger_error(
				'Undefined property via __get(): ' . $name .
				' in ' . $trace[0]['file'] .
				' on line ' . $trace[0]['line'],
				E_USER_NOTICE);*/
		return null;
	}

	public function __isset($name) {
		return isset($this->syssession[$this->userid][$name]);
	}

	public function __unset($name) {
		unset($this->syssession[$this->userid][$name]);
	}

	/* Params setter/getter */
	public function ssnparam($pname, $pvalue = null) {
		if ($pvalue === null)
			return $this->syssession[$this->userid][$pname];
		else
			$this->syssession[$this->userid][$pname] = $pvalue;
	}

	function Session(){
		$this->time = time();
		$this->userlevel = ACCESS_MODE;
		$this->startSession();
	}

	function startSession(){
		global $stk_database;
		session_name('stksession');
		session_start();

		$this->syssession = &$_SESSION;
		$this->db_ok = $stk_database->db_ok;

		/* Determine if user is logged in */
		$this->logged_in = $this->db_ok && $this->checkSTKLogin();

		if (!$this->logged_in) {
			$this->username = $_SESSION['username'] = GUEST_NAME;
			$this->userlevel = GUEST_LEVEL;
		}
		/* Update users last active timestamp */
		else {
			// $stk_database->registerLoginSession($this->username, $this->ofid, $this->userid, $this->time);
		}

		/* Set referrer page */
		if (isset($_SESSION['url']))
			$this->referrer = $_SESSION['url'];
		else
			$this->referrer = "/";

		/* Set current url */
		$this->url = $_SESSION['url'] = $_SERVER['PHP_SELF'];
	}

	function checkSTKLogin() {
		global /*$stk_database,*/ $logger;

		//$logger->log("checkSTKLogin(sess):\n".print_r($_SESSION, true));
		//$logger->log("checkSTKLogin(post):\n".print_r($_POST, true));
		/* Check if user has been remembered */
		/*if (isset($_COOKIE[COOKIE_NAME_LOGINNUMB]) &&
			isset($_COOKIE[COOKIE_NAME_LOGINNAME]) &&
			isset($_COOKIE[COOKIE_NAME_LOGINPASS])) {
			$this->ofnumber  = $_SESSION['ofnumber']  = $_COOKIE[COOKIE_NAME_LOGINNUMB];
			$this->username  = $_SESSION['username']  = $_COOKIE[COOKIE_NAME_LOGINNAME];
			$this->userwebid = $_SESSION['userwebid'] = $_COOKIE[COOKIE_NAME_LOGINPASS];
		}*/

		/* Username and userid have been set and not guest */
		if (isset($_SESSION['stk_accountid']) && isset($_SESSION['userid']) && isset($_SESSION['stk_emitterkcid']) &&
			$_SESSION['username'] != GUEST_NAME){
			/* Confirm that username and userid are valid */
			/* ToDo: temporarily disabled ONLY-SINGLE-LOGIN-TO-OFFICE behaviour
			/*if($stk_database->confirmUserID($_SESSION['stk_accountid'], $_SESSION['stk_emitterkcid'], $_SESSION['userid']) != 0){
				/* Variables are incorrect, user not logged in * /
				unset($_SESSION['username']);
				unset($_SESSION['userid']);
				unset($_SESSION['stk_accountid']);
				unset($_SESSION['stk_emitterkcid']);
				return false;
			}*/

			/* User is logged in, set class variables */
			$this->username = $_SESSION['username'];//$this->userinfo['username'];
			$this->userid = $_SESSION['userid'];//$this->userinfo['userid'];
			//$this->userlevel = $this->userinfo['userlevel'];

			$this->stk_accountinfoex = $_SESSION['stk_accountinfoex'];
			$this->stk_accountcurrencyid = $_SESSION['stk_accountcurrencyid'];
			$this->stk_accountid = $_SESSION['stk_accountid'];
			$this->stk_emitterkcid = $_SESSION['stk_emitterkcid'];
			$this->stk_pin = $_SESSION['stk_pin'];

			$this->stk_case_login = $_SESSION['stk_case_login'];
			return true;
		}
		/* User not logged in */
		else{
			return false;
		}
	}

	function stklogin($stkaccid, $stkpin, $stkchecknum) {
		global $stk_database, $form;

		$lg_emitkcid = 0;
		$lg_userid = 'null';

		$field = "checknumber";
		if (!isset($_SESSION['image_value']) || empty($_POST['checknumber']) ||
			$_POST['checknumber'] != $_SESSION['image_value']) {
			unset($_SESSION['image_value']);
			$form->setError($field, "*   ");
			return false;
		}
		unset($_SESSION['image_value']);

		$field = "accid";
		if (!$stkaccid || strlen($stkaccid = trim($stkaccid)) == 0) {
			$form->setError($field, "*    ");
		} else {
			/* Check if username is not alphanumeric */
			//if (!eregi("^([0-9a-z])*$", $subuser)){
			//if (!eregi("^([0-9])*$", $stkaccid))
			if (!preg_match('/^[0-9]*$/', $stkaccid))
				$form->setError($field, "*        0..9");
		}

		$field = "pin";
		if (!$stkpin) {
			$form->setError($field, "*   -");
		} else {
			$stk_database->logLoginSession($_POST['accid'],$lg_emitkcid,$_POST['pin'],$lg_userid,$this->time);
			$this->stk_accountinfo = $stk_database->getSTKAttributes($_POST['pin'], $_POST['accid']);
			if (!$this->stk_accountinfo)
				$form->setError($field, "*  !    -  .");
		}

		if ($form->num_errors > 0)
			return false;

		$this->username  = $_SESSION['username'] = $stkaccid;
		$this->stk_accountid = $_SESSION['stk_accountid'] = $this->stk_accountinfo['ACCOUNTID'];
		$this->stk_emitterkcid = $_SESSION['stk_emitterkcid'] = $this->stk_accountinfo['EMITTERKCID'];
		$this->userid = $_SESSION['userid'] = $this->generateRandID();
		$this->stk_pin = $_SESSION['stk_pin'] = $_POST['pin'];

		$this->stk_case_login = $_SESSION['stk_case_login'] = '';

		$stk_database->registerLoginSession($this->stk_accountid, $this->stk_emitterkcid, $_POST['pin'], $this->userid, $this->time);

		$this->stk_accountinfoex = $_SESSION['stk_accountinfoex'] = $stk_database->getSTKInfo($this->stk_accountid, $this->stk_emitterkcid);
		$this->stk_accountcurrencyid = $_SESSION['stk_accountcurrencyid'] = $this->stk_accountinfoex['CURRENCYID'];
		//$logger->log("getSTKInfo=" . print_r($this->stk_accountinfoex, true));

		return true;
	}

	/**
	 * logout - Gets called when the user wants to be logged out of the
	 * website. It deletes any cookies that were stored on the users
	 * computer as a result of him wanting to be remembered, and also
	 * unsets session variables and demotes his user level to guest.
	 */
	function logout() {
		if (isset($_COOKIE['cookname']) && isset($_COOKIE['cookid'])) {
			setcookie("cookname", "", time()-COOKIE_EXPIRE, COOKIE_PATH);
			setcookie("cookid",   "", time()-COOKIE_EXPIRE, COOKIE_PATH);
		}

		session_unset();
		session_destroy();
		$_SESSION = array();

		$this->logged_in = false;
		$this->username  = GUEST_NAME;
		$this->userlevel = GUEST_LEVEL;
	}

	/**
	 * isAdmin - Returns true if currently logged in user is
	 * an administrator, false otherwise.
	 */
	function isAdmin(){
		return ($this->userlevel == ADMIN_LEVEL || $this->username  == ADMIN_NAME);
	}

	/**
	 * generateRandID - Generates a string made up of randomized
	 * letters (lower and upper case) and digits and returns
	 * the sha1 hash of it to be used as a userid.
	 */
	function generateRandID(){
		return sha1($this->generateRandStr(128));
	}

	/**
	 * generateRandStr - Generates a string made up of randomized
	 * letters (lower and upper case) and digits, the length
	 * is a specified parameter.
	 */
	function generateRandStr($length){
		$randstr = "";
		for ($i = 0; $i < $length; $i++) {
			$randnum = mt_rand(0, 61);
			if ($randnum < 10) {
				$randstr .= chr($randnum + 48);
			} else if ($randnum < 36) {
				$randstr .= chr($randnum + 55);
			} else {
				$randstr .= chr($randnum + 61);
			}
		}
		return $randstr;
	}

	/**
	 * initStatFilters - initializes statistics page filters with some initial values if needed
	 */
	function initStatFilters() {
		if (!isset($this->sf_startdate)) {
			$this->sf_startdate = date("d.m.Y", mktime(0,0,0,date("m")-6,date("d"),date("Y")));
			$this->sf_enddate = date("d.m.Y");
			return true;
		}
		return false;
	}
};

$session = new Session;

/* Initialize form object */
$form = new Form;

?>
