<?php
/*
 * Created on 09.04.2007
 */

require_once(dirname(__FILE__).'/constants.php');
require_once(dirname(__FILE__).'/session.php');
require_once 'MDB2.php';
PEAR::setErrorHandling(PEAR_ERROR_RETURN);

class STK_IBDB {
	public $connection;         //The database connection
	public $db_ok;              //Indicates problems connecting to database
	public $num_active_users;   //Number of active users viewing site
	public $num_active_guests;  //Number of active guests viewing site
	public $num_members;        //Number of signed-up users

	// Constructor
	function STK_IBDB() {
		global $logger;

		/* Make connection to database */
		$dsn = DB_ENGINE.'://'.STK_DB_USER.':'.STK_DB_PASS.'@'.STK_DB_HOST.'/'.STK_DB_FILE;
		$this->connection =& MDB2::factory($dsn, false);
		if (PEAR::isError($this->connection)) {
			$this->db_ok = false;
			$logger->log("STK_IBDB Fatal Error!!!");
			return;
		}
		$this->db_ok = true;

		$this->connection->setOption('field_case', CASE_UPPER);
		$this->connection->setOption('portability', MDB2_PORTABILITY_NUMROWS | MDB2_PORTABILITY_FIX_CASE);
		$this->connection->setFetchMode(MDB2_FETCHMODE_ASSOC);
		$this->connection->LoadModule('Extended');
	}

	/**
	 * registerLoginSession - Creates record in the database's
	 * main web_cache table.
	 * Returns true on success, false otherwise.
	 */
	function registerLoginSession($acc_id, $acc_emitkcid, $acc_pin, $acc_userid, $time){
		global $logger;

		/* If admin sign up, give admin user level */
		$doinsert = 0;
		$q = "SELECT acc_id FROM ".TB_WEB_CACHE." where acc_id=$acc_id and acc_emitkcid=$acc_emitkcid";
		$result = $this->connection->query($q);
		if (PEAR::isError($result)) {
			$doinsert = 1;
			$logger->log("registerLoginSession($acc_id,$acc_emitkcid) CHECK:\n".print_r($result, true));
		} else {
			if(!$result->fetchRow())
				$doinsert = 1;
		}

		$q = $doinsert == 1 ?
			"INSERT INTO ".TB_WEB_CACHE." (ACC_ID,ACC_EMITKCID,ACC_PIN,ACC_USERID,last_time) VALUES ($acc_id, $acc_emitkcid, '$acc_pin', '$acc_userid', $time)" :
			"UPDATE ".TB_WEB_CACHE." SET acc_userid='$acc_userid', last_time=$time where acc_id=$acc_id";
		$logger->log("registerLoginSession($acc_id, $acc_emitkcid, $acc_pin, $acc_userid, $time):$doinsert");
		return $this->connection->query($q);
	}

	function confirmUserID($accountid, $emitterkcid, $userid){
		//TODO: need user confirm
		global $logger;

		$logger->log("confirmUserID($accountid, $emitterkcid, $userid)");

		/* Add slashes if necessary (for query) */
		//if(!get_magic_quotes_gpc()) {
		//	$username = addslashes($username);
		//}

		/* Verify that user is in database */
		$q = "select acc_userid from ".TB_WEB_CACHE." where (acc_id=$accountid) and (acc_emitkcid= $emitterkcid)";
		//$q = "select userid from ".TB_WEB_CACHE." where acc_id in"
		//	." (select of_id from tb_offices where of_number='$username')";
		$result = $this->connection->query($q);
		if(PEAR::isError($result)) {
			$logger->log(print_r($result, true));
			return 1;
		}
		if(!$dbarray = $result->fetchRow()) {
			$logger->log("confirmUserID: NULL".print_r($dbarray, true));
			return 1; //Indicates username failure
		}

		/* Retrieve userid from result, strip slashes */
		$dbarray['ACC_USERID'] = stripslashes($dbarray['ACC_USERID']);
		$userid = stripslashes($userid);

		/* Validate that userid is correct */
		if($userid == $dbarray['ACC_USERID'])
			return 0; //Success! Username and userid confirmed
		else
			return 2; //Indicates userid invalid
	}

	/** Log login session
	 *  for administrative and history uses
	 */
	function logLoginSession($acc_id,$acc_emitkcid,$acc_pin,$acc_userid,$time){
		global $logger;

		$remote_addr = $_SERVER['REMOTE_ADDR'];
		$q = "Insert into " . TB_WEB_LOG . " (acc_id,acc_emitkcid,acc_pin,lg_time,lg_host) values ($acc_id,$acc_emitkcid,'$acc_pin',$time,'$remote_addr')";
		$logger->log("logLoginSession($acc_id,$acc_emitkcid,$acc_pin,$acc_userid,$time,$remote_addr)");
		return $this->connection->query($q);
	}

	/**
	 * Provides simple query interface
	 */
	function query($query){
		return $this->connection->query($query);
	}

	/**
	 * getQueryResultAsArray
	 */
	function getQueryResultAsArray($query, $types = null){
		global $logger;

		$result = $this->connection->queryAll($query, $types);
		if (PEAR::isError($result)) {
			$logger->log("getQueryResultAsArray($query) ERR:\n".print_r($result, true));
			$result = null;
		}
		$logger->log("getQueryResultAsArray($query) OK:\n".print_r($result, true));
		return $result;
	}

	/**	   
	 * 	 : $pincode- , $accid-  ()
	 * 	 : ACCOUNTID,EMITTERKCID
	 */
	function getSTKAttributes($pincode, $accid) {
		global $logger;

		// 1 step: get AccountID EmitterKCID by PIN
		$q = "Select ACCOUNTID,EMITTERKCID From TBPINS where PIN='$pincode' and ACCOUNTID=$accid";

		$result = $this->connection->query($q);
		if (PEAR::isError($result)) {
			$logger->log("getSTKAttributes($pincode) ERR:\n".print_r($result, true));
			return null;
		}

		/* Error occurred, return given name by default */
		if ((!$dbarray = $result->fetchRow()) || !$dbarray['ACCOUNTID'])
			return null;

		return $dbarray;
	}

	/**
	 *    
	 *   : $stk_accountid -  , $stk_emitterkcid -  
	 */
	function getSTKInfo($stk_accountid,$stk_emitterkcid) {
		global $logger;

		$q = "Select * From tbAccounts a,tbAccountsUpdate b where "
			."a.ACCOUNTID=$stk_accountid and a.EMITTERKCID=$stk_emitterkcid and "
			."a.EMITTERKCID=b.EMITTERKCID and a.ACCOUNTID=b.ACCOUNTID";
		$result = $this->connection->query($q);

		if (PEAR::isError($result)) {
			$logger->log("getSTKInfo($stk_accountid) ERR:\n".print_r($result, true));
			return null;
		}

		$dbarray = $result->fetchRow();
		return $dbarray;
	}

	/**
	 *       .
	 */
	function getStatusInfo($status_code) {
		switch ($status_code) {
			case 0:
				$status_info = '';
				break;
			case -1:
				$status_info = '  ';
				break;
			case -2:
				$status_info = '    ';
				break;
			case -3:
				$status_info = '   ';
				break;
			case -4:
				$status_info = '    ';
				break;
			case -9:
				$status_info = '   ';
				break;
			case -10:
				$status_info = '';
				break;
			case -11:
				$status_info = '   ';
				break;
			case -12:
				$status_info = '  ';
				break;
			case -13:
				$status_info = '   ';
				break;
			case -14:
				$status_info = ',    ';
				break;
			default:
				$status_info = ' ';
		}
		return $status_info;
	}

	/**
	 *        .
	 */
	function getTransferCashStatusInfo($status_code) {
		switch ($status_code) {
			case 0:
				$status_info = '   ';
				break;
			case -681:
				$status_info = '   ';
				break;
			case -684:
				$status_info = '    ,   ';
				break;
			case -683:
				$status_info = '     ';
				break;
			case -682:
				$status_info = '  ';
				break;
			case -685:
				$status_info = '    ';
				break;
			case -9999:
				$status_info = '   ';
				break;
			default:
				$status_info = ' ';
		}
		return $status_info;
	}

	/**
	 *        .
	 *   :	$id  ,
	 * 						$fieldname    ,
	 * 						$tablename  ,
	 * 						$fieldid    .
	 */
	function getSTKNameByID($id,$fieldname,$tablename,$fieldid) {
		global $logger;
		$q = "Select $fieldname from $tablename where ($fieldid=$id)";
		$result = $this->connection->query($q);
		if (PEAR::isError($result)) {
			$logger->log("getSTKNameByID($id) ERR:\n".print_r($result, true));
			return null;
		}

		$dbarray = $result->fetchRow();
		$resvalue = $dbarray[$fieldname];
		//return $dbarray;
		return $resvalue;
	}

	/**
	 *     .
	 */
	function int_GetAccountInfo($accountid,$emitterkcid) {
		global $logger;

		$q = "Select * From int_GetAccountInfo($accountid,$emitterkcid)";
		$result = $this->connection->query($q);
		if (PEAR::isError($result)) {
			$logger->log("int_GetAccountInfo($accountid,$emitterkcid) ERR:\n".print_r($result, true));
			return null;
		}

		$dbarray = $result->fetchRow();
		return $dbarray;
	}

	/**
	 *    .
	 */
	function getPersonalAccount($accountid,$emitterkcid) {
		global $logger;

		$q = "Select PersonalAccount From tbPersonalAccounts where EmitterKCID=$emitterkcid and AccountID=$accountid";
		$result = $this->connection->query($q);
		if (PEAR::isError($result)) {
			$logger->log("GetPersonalAccount($accountid,$emitterkcid) ERR:\n".print_r($result, true));
			return null;
		}

		$dbarray = $result->fetchRow();
		$db_paccount = $dbarray['PERSONALACCOUNT'] ? $dbarray['PERSONALACCOUNT'] : '';
		return $db_paccount;
	}

	/**
	 *    .
	 */
	function GetAllCurrencies($curid) {
		global $logger;

		$q = "Select * From tbCurrency where CurrencyID>0";
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("GetAllCurrencies($curid) ERR:\n".print_r($result, true));
			return null;
		}

		//$dbarray = $result->fetchRow();
		return $result;
	}

	/**
	 *       .
	 */
	function GetCurrencyNameByID($cur_id) {
		global $logger;

		$q = "Select * From tbCurrency where (CurrencyID=$cur_id)";
		$result = $this->connection->query($q);
		if (PEAR::isError($result)) {
			$logger->log("GetCurrencyNameByID($cur_id) ERR:\n".print_r($result, true));
			return null;
		}

		$dbarray = $result->fetchRow();
		$res_cur = $dbarray['CURRENCYNAME'] ? $dbarray['CURRENCYNAME'] : '' ;
		return $res_cur;
	}

	/**
	 *     .
	 */
	function GetAllMailBoxTypes($mbid) {
		global $logger;

		$q = "Select BoxTypeID,BoxTypeName From tbBoxTypes where (BoxTypeID>0)";
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("GetAllMailBoxTypes($mbid) ERR:\n".print_r($result, true));
			return null;
		}

		return $result;
	}

	/**
	 *      .
	 */
	function GetMailBoxes($accountid,$emitterkcid) {
		global $logger;

		$q = "Select * from tbBoxes where EmitterKCID=$emitterkcid and AccountID=$accountid";
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("GetMailBoxes($accountid,$emitterkcid) ERR:\n".print_r($result, true));
			return null;
		}
		return $result;
	}

	/**
	 *       ,  javascript
	 */
	function getMBTypesList_htmlcode($arr) {
		$result = "";//"var int_nums = new Array();";
		foreach ($arr as $row) {
			//$mb_tname = getSTKNameByID($row['BOXTYPEID'],"BOXTYPENAME","tbBoxType","BOXTYPEID");
			$result .= "int_mb_tnames['".$row['BOXTYPEID']."'] = '".$row["BOXTYPENAME"]."';";
		}
		return $result;
	}

	/**
	 *       .
	 */
	function GetNoteBookRec($accountid,$emitterkcid){
		global $logger;

		$q = "Select * from tbNotePad where (EmitterKCID=$emitterkcid) and (AccountID=$accountid) order by ADDDATE";
		$result = $this->connection->query($q);
		if (PEAR::isError($result)) {
			$logger->log("GetNoteBookRec($accountid) ERR:\n".print_r($result, true));
			return null;
		}
		return $result;
	}

	/**
	 *  ()    
	 */
	function addNotebookRec($accountid, $emitterkcid, $realnumber, $numberb, $addinfo) {
		//global $logger;

		$q = "select * from web_addnotepadnumber($accountid, $emitterkcid, '$realnumber', '$numberb', 0, null, '$addinfo')";
		$result = $this->getQueryResultAsArray($q);
		if (!empty($result))
			$result = $result[0]['FLAGSOUT'];
		return $result;
	}

	/**
	 *     
	 */
	function delNotebookRec($accountid, $emitterkcid, $realnumber) {
		//global $logger;

		$q = "select * from web_addnotepadnumber($accountid, $emitterkcid, '$realnumber', '', 1, null, '')";
		$result = $this->getQueryResultAsArray($q);
		if (!empty($result))
			$result = $result[0]['FLAGSOUT'];
		return $result;
	}

	/**
	 *      -
	 */
	function GetPINsPin($accountid,$emitterkcid) {
		global $logger;

		$q = "Select PIN from tbPins where EmitterKCID=$emitterkcid and AccountID=$accountid";
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("GetPINs($accountid) ERR:\n".print_r($result, true));
			return null;
		}
		return $result;
	}

	/**
	 *      .
	 *
	 * @param unknown_type $accountid
	 * @param unknown_type $emitterkcid
	 * @return unknown
	 */
	function GetPINsNum($accountid, $emitterkcid) {
		global $logger;

		$q = "Select PinPhone from tbPinPhones where EmitterKCID=$emitterkcid and AccountID=$accountid";
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("GetPINs($accountid) ERR:\n".print_r($result, true));
			return null;
		}
		return $result;
	}

	/**
	 *     .
	 */
	function getSTKFreePINs() {
		global $logger;

		$q = "Select PIN from tbPins where AccountID=-1 or AccountID is NULL";
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("getSTKFreePINs() ERR:\n".print_r($result, true));
			return null;
		}
		return $result;
	}

	/**
	 *
	 */
	function getSTKAccountGroups($auth_type_id) {
		global $logger;

		$auth_type_id = 1; //PIN
		$q = "Select AccountGroupID,AccountGroupName,ParentID From tbAccountGroups "
			."where (AuthorizationTypeID=$auth_type_id) AND ((ParentID IS NULL)OR(GLevel=2)) AND (AccountGroupID<>-1) order by AccountGroupName";
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("getSTKAccountGroups($auth_type_id) ERR:\n".print_r($result, true));
			return null;
		}
		return $result;
	}

	/**
	 *        .
	 *
	 * @param unknown_type $accountid
	 * @param unknown_type $emitterkcid
	 * @return unknown
	 */
	function getSTKSecurityPhones($accountid,$emitterkcid){
		global $logger;

		$q = "Select * from tbSecurityPhones where EmitterKCID=$emitterkcid and AccountID=$accountid";
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("getSTKSecurityPhones($accountid) ERR:\n".print_r($result, true));
			return null;
		}
		return $result;
	}

	/**
	 *
	 */
	function getSTKSecurityStatus($accountid,$emitterkcid) {
		global $logger;

		$q = "Select SecurityStatus From tbAccounts where EmitterKCID=$emitterkcid and AccountID=$accountid";
		$result = $this->connection->query($q);
		if (PEAR::isError($result)) {
			$logger->log("getSTKSecurityStatus($accountid) ERR:\n".print_r($result, true));
			return null;
		}

		$dbarray = $result->fetchRow();
		return $dbarray['SECURITYSTATUS'];
		//   if (!$dbarray['SECURITYSTATUS']) {
		//      $res_status = 0;
		//   } else {
		//      $res_cur = $dbarray['SECURITYSTATUS'];
		//   }
		//   return $res_status;
	}

	/**
	 * Account Reports History
	 */
	function getSTKReportHistory($accountid,$emitterkcid){
		global $session, $logger;

		$q= "SELECT a.CreateDate,a.Creator,a.CurrencyID,a.AccountGroupID,a.FIO,a.MAXCONNECTIONS,a.ROUMINGMODE,"
			."b.Summ,b.status,b.connections,"
			."c.AccountGroupName,c.AuthorizationTypeID,"
			."d.TarifPoliticName,"
			."e.CurrencyName,"
			."f.AccountGts,"
			."g.PersonalAccount,"
			."h.OrderID,h.DateOfSell,h.TicketStatus,h.OpCloseID,h.OpCloseName,h.CloseTime, "
			."q.ACCOUNTTYPENAME "
			."FROM tbAccounts a "
			."LEFT OUTER JOIN tbAccountsUpdate b ON (a.EmitterKCID=b.EmitterKCID) AND (a.AccountID=b.AccountID) "
			."LEFT OUTER JOIN tbAccountGroups c ON (a.AccountGroupID=c.AccountGroupID) "
			."LEFT OUTER JOIN tbTarifPolitics d ON (c.TarifPoliticID=d.TarifPoliticID) "
			."LEFT OUTER JOIN tbCurrency e ON (a.CurrencyID=e.CurrencyID) "
			."LEFT OUTER JOIN tbGts f ON (a.EmitterKCID=f.EmitterKCID) AND (a.AccountID=f.AccountID) "
			."LEFT OUTER JOIN tbPersonalAccounts g ON (a.EmitterKCID=g.EmitterKCID) AND (a.AccountID=g.AccountID) "
			."LEFT OUTER JOIN tbTickets h ON (a.EmitterKCID=h.EmitterKCID) AND (a.AccountID=h.AccountID) "
			."LEFT OUTER JOIN TBACCOUNTVALUES p ON (a.accountvalueid=p.accountvalueid) "
			."LEFT OUTER JOIN TBACCOUNTTYPES q ON (p.accounttypeid=q.accounttypeid) "
			."WHERE (a.EmitterKCID=$emitterkcid) AND (a.AccountID=$accountid)";

		$result = $this->connection->query($q);
		if (PEAR::isError($result)) {
			$logger->log("getSTKReportHistory($accountid,$emitterkcid) ERR:\n".print_r($result, true));
			return null;
		}
		$dbarray = $result->fetchRow();
		return $dbarray;
	}

	/**
	 * Account Reports History AddSum
	 *  ftime - from time, ctime - to time
	 */
	function getSTKReportAddSumm($accountid, $emitterkcid, $ftime, $ctime) {
		global $logger;

		$ftime = $ftime . ' 00:00:00';
		$ctime = $ctime . ' 23:59:59';
		$q= "SELECT a.AddDate,a.AddBy,a.Summ,b.CurrencyName,a.addinfo "
			."FROM tbAddSumm a "
			."LEFT OUTER JOIN tbCurrency b ON (a.CurrencyID=b.CurrencyID) "
			."WHERE (a.EmitterKCID=$emitterkcid) AND (a.AccountID=$accountid) AND (a.AddDate>='$ftime') "
			."AND (a.AddDate<='$ctime') AND (a.Summ>0)";
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("getSTKReportAddSumm($accountid,$emitterkcid,$ftime,$ctime) ERR:\n".print_r($result, true));
			return null;
		}
		return $result;
	}

	function getSTKReportDeductionSumm($accountid,$emitterkcid,$ftime,$ctime) {
		global $logger;

		$ftime = $ftime . ' 00:00:00';
		$ctime = $ctime . ' 23:59:59';
		$q= "SELECT a.AddDate,a.AddBy,a.Summ,b.CurrencyName,a.addinfo "
			."FROM tbAddSumm a "
			."LEFT OUTER JOIN tbCurrency b ON (a.CurrencyID=b.CurrencyID) "
			."WHERE (a.EmitterKCID=$emitterkcid) AND (a.AccountID=$accountid) AND (a.AddDate>='$ftime') "
			."AND (a.AddDate<='$ctime') AND (a.Summ<0)";
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("getSTKReportDeductionSumm($accountid,$emitterkcid,$ftime,$ctime) ERR:\n".print_r($result, true));
			return null;
		}
		return $result;
	}

	function getSTKReportTarifPoliticChanges($accountid,$emitterkcid,$ftime,$ctime) {
		global $logger;

		$ftime = $ftime . ' 00:00:00';
		$ctime = $ctime . ' 23:59:59';
		$q = "select a.changedate, p1.tarifpoliticname as tarifpoliticnameold, p2.tarifpoliticname as tarifpoliticnamenew"
			." from tbaccountgroupschange a"
			." left join tbaccountgroups g1 on (g1.accountgroupid = a.oldaccountgroupid)"
			." left join tbaccountgroups g2 on (g2.accountgroupid = a.newaccountgroupid)"
			." left join tbtarifpolitics p1 on (g1.tarifpoliticid = p1.tarifpoliticid)"
			." left join tbtarifpolitics p2 on (g2.tarifpoliticid = p2.tarifpoliticid)"
			." where a.emitterkcid = $emitterkcid and a.accountid = $accountid and"
			." 	  a.changedate >= '$ftime' and a.changedate <= '$ctime'"
			." order by a.changedate";
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("getSTKReportTarifPoliticChanges($accountid,$emitterkcid,$ftime,$ctime) ERR:\n".print_r($result, true));
			return null;
		}
		return $result;
	}

	function getSTKReport1($accountid,$emitterkcid,$ftime,$ctime,$serviceidin){
		global $logger;

		$ftime = $ftime . ' 00:00:00';
		$ctime = $ctime . ' 23:59:59';
		$q = "SELECT "
			."a.AccountID,a.EmitterKCID,a.ServiceID,a.StartTime,a.StrParam,a.RealVolume, "
			."a.PayableVolume,a.FloatCash1,a.FloatCash2,a.Floatgraph,a.OpID,a.TechInt1,"
			."b.Pay,b.RestSumm,b.BlockType,"
			."c.GeographyName,"
			."d.SessionID,d.LineIn,d.NumberA,d.AUTHORIZATIONTYPE,"
			."e.AccountGts,"
			."f.PersonalAccount, "
			."p.tarifpoliticname "
			."FROM TBSERVDETAILREPORT a "
			."LEFT OUTER JOIN tbServListReport b ON (a.ServiceKCID=b.ServiceKCID) AND (a.ServiceBlockID=b.ServiceBlockID) "
			."LEFT OUTER JOIN tbGeography c ON (a.IntCash3=c.GeographyID) "
			."LEFT OUTER JOIN TBSESSIONSREPORT d ON (b.SessionKCID=d.SessionKCID) AND (b.SessionID=d.SessionID) "
			."LEFT OUTER JOIN tbGts e on (a.EmitterKCID=e.EmitterKCID) AND (a.AccountID=e.AccountID) "
			."LEFT OUTER JOIN tbPersonalAccounts f on (a.EmitterKCID=f.EmitterKCID) AND (a.AccountID=f.AccountID) "
			."left outer join tbtarifpolitics p on (d.tarifpoliticid = p.tarifpoliticid) "
			."WHERE (a.EmitterKCID=$emitterkcid) AND (a.AccountID=$accountid) AND (a.StartTime>='$ftime') AND (a.StartTime<='$ctime') AND (a.IntCash5=1) AND "
		."((-999=$serviceidin) OR (a.ServiceID=$serviceidin)) AND ((a.TechInt2<500) OR (a.TechInt2 IS NULL)) "
		."ORDER BY b.SessionID,b.BLOCKTYPE DESCENDING,a.StartTime";
		//$logger->log("getSTKReport1($q)");
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("getSTKReport1($accountid,$emitterkcid,$ftime,$ctime,$serviceidin) ERR:\n".print_r($result, true));
			return null;
		}
		return $result;
	}

	function getSTKAllServices($servgroupid){
		global $logger;

		$q= "Select ServiceID,ServiceName From tbServices where (ServiceGroupID=$servgroupid)";
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("getSTKAllServices($servgroupid) ERR:\n".print_r($result, true));
			return null;
		}
		return $result;
	}

	function getSTKServiceNames(){
		global $logger;

		$q= "Select ServiceID,ServiceName From tbServices";
		$result = $this->connection->queryAll($q);
		if (PEAR::isError($result)) {
			$logger->log("getSTKServiceNames() ERR:\n".print_r($result, true));
			return null;
		}
		return $result;
	}

	function transferCash($op_id,$spin,$summin,$acc_out) {
		global $logger;

		$mdate = date("d.m.Y H:i:s");
		$q= "select a.sessionid, c.movecashstatus, c.summout
			from ses_opensession ('$mdate',-1,-1,'',-1,$op_id,0,-1,'',2) a,
			ses_authorizebypin (a.sessionid,'$mdate',0,'$spin','') b,
			ses_movecash (a.sessionid,'$summin',0,'$acc_out','$mdate') c,
			ses_closesession (a.sessionid,'$mdate',0,0,'') d";
		$result = $this->connection->query($q);
		if (PEAR::isError($result)) {
			$logger->log("transferCash($op_id,$summin,$acc_out) ERR:\n".print_r($result, true));
			return null;
		}
		$dbarray = $result->fetchRow();
		return $dbarray;
	}

	/**
	 * PROCEDURE WEB_TRANSFER_CASH (
	 * OPERNAME VARCHAR(128),
	 * SUMMIN DOUBLE PRECISION,
	 * ACCOUNTID INTEGER,
	 * EMITTERKCID INTEGER,
	 * TRANSFERTIME DATE,
	 * FLAGSIN INTEGER,
	 * ADDINFO VARCHAR(128),
	 * OPID INTEGER,
	 * CURRENCYIDIN INTEGER,
	 * ADDINDEX INTEGER,
	 * ACCOUNTIDOUT INTEGER)
	 * RETURNS (
	 * TRANSFERSTATUS INTEGER,
	 * SUMMOUT DOUBLE PRECISION,
	 * CURRENCYID INTEGER,
	 * FLAGSOUT INTEGER)
	 */
	/* :
		flagsin = 0 -      
		flagsin = 1 -     
		flagsin = 2 -       
		flagsin = 3 -       
		flagsin = 4 -      
	*/
	function transferCashEx($summin, $accountid, $emitterkcid, $addinfo, $accountidout, $currencyid) {
		global $logger;
		$flagsin = 0;  //     
		$opid = -80;
		$mdate = date("d.m.Y H:i:s");
		$qlog = "web_transfer_cash('".EXTERNAL_OPERATION_STKCASHTRANSFER_OPERNAME."', " .
				"$summin, $accountid, $emitterkcid, '$mdate', $flagsin, '$addinfo', $opid, null, $currencyid, null, $accountidout)";
		$q = "select * from " . $qlog;

		$result = $this->connection->query($q);
		if (PEAR::isError($result)) {
			$logger->log("transferCashEx($qlog) ERR:\n".print_r($result, true));
			return null;
		}
		$dbarray = $result->fetchRow();
		return $dbarray;
	}

	function transferCashExternal($mode, $summin, $accountid, $emitterkcid, $addinfo, $transact = null) {
		global $logger;

		switch ($mode) {
			case 'start':
				$flagsin = 2;  //      
				break;
			case 'commit':
				$flagsin = 3;  //      
				break;
			case 'rollback':
				$flagsin = 4;  //     
				break;
			default:
				return null;
		}

		$opid = -80;
		$mdate = date("d.m.Y H:i:s");
		$qlog = "web_transfer_cash('".EXTERNAL_OPERATION_STKCASHTRANSFER_OPERNAME."', " .
				"$summin, $accountid, $emitterkcid, '$mdate', $flagsin, '$addinfo', $opid, $transact, null, null, null)";
		$q = "select * from " . $qlog;

		$result = $this->connection->query($q);
		if (PEAR::isError($result)) {
			$logger->log("transferCashEx($qlog) ERR:\n".print_r($result, true));
			return null;
		}
		$dbarray = $result->fetchRow();
		$logger->log("transferCashEx($qlog):".print_r($dbarray, true));
		return $dbarray;
	}

	function getCaseTypes() {
		$q = "select documenttypeid,documentname from tbdocumenttype";
		return $this->getQueryResultAsArray($q);
	}

	function getCaseAttributes($case_login) {
		//global $logger;

		$q = "select a.caseid_login, a.createdate, b.documentname, c.currencyname, a.casecurrency, a.addinfo, a.lastlogin" .
			" from tbclientcase a" .
			" inner join tbdocumenttype b on (a.documenttypeid = b.documenttypeid)" .
			" inner join tbcurrency c on (a.casecurrency = c.currencyid)" .
			" where a.caseid_login='$case_login'";

		$result = $this->getQueryResultAsArray($q);
		if (!empty($result))
			$result = $result[0];
		return $result;
	}

	function getCaseAccountsList($case_login) {
		//global $logger;

		$q = "select a.ADDINFO, b.createdate, b.roumingmode, b.fio, b.maxconnections, b.starttime, c.status, c.summ, c.connections" .
			" from TBCLIENTCARD a" .
			" join tbAccounts b on (a.EmitterKCID=b.EmitterKCID) and (a.AccountID=b.AccountID)" .
			" join tbAccountsUpdate c on (a.EmitterKCID=c.EmitterKCID) and (a.AccountID=c.AccountID)" .
			" where a.caseid_login='$case_login'" .
			" order by b.createdate";

		$result = $this->getQueryResultAsArray($q);
		return $result;
	}

	function addCaseCard($case_login, $case_pwd, $cardpin, $comment) {
		//global $logger;

		$q = "select * from add_client_card('$case_login', '$case_pwd', '$cardpin', '$comment', 2, '', 1)";
		$result = $this->getQueryResultAsArray($q);
		$result = !empty($result) ? $result[0]['FLAGSOUT'] : null;
		return $result;
	}

	function delCaseCard($case_login, $case_pwd, $cardpin) {
		//global $logger;

		$q = "select * from add_client_card('$case_login', '$case_pwd', '$cardpin', null, 2, '', 0)";
		$result = $this->getQueryResultAsArray($q);
		$result = !empty($result) ? $result[0]['FLAGSOUT'] : null;
		return $result;
	}

	function allocCaseCard($case_login, $method, $allowblocked, $days) {
		//global $logger;

		$allowblocked = $allowblocked == 0 ? 0 : 1;
		$days = $method == 0 ? 0 : intval($days);

		$q = "select * from a_reallocate_money($allowblocked, '$case_login', $days, 0)";
		$result = $this->getQueryResultAsArray($q);
		$result = !empty($result) ? $result[0]['FLAGSOUT'] : null;
		return $result;
	}

}; //class STK_IBDB

$stk_database = new STK_IBDB;
?>
